@@ -28,7 +28,7 @@
 #include "libbb.h"
 
 #define CONFIG_FEATURE_TAR_OLDGNU_COMPATABILITY 1
-// #define CONFIG_FEATURE_TAR_GNU_EXTENSIONS
+#define CONFIG_FEATURE_TAR_GNU_EXTENSIONS
 
 #ifdef CONFIG_FEATURE_TAR_GNU_EXTENSIONS
 static char *longname = NULL;
@@ -657,7 +657,8 @@ file_header_t *get_header_tar(FILE *tar_stream)
 # ifdef CONFIG_FEATURE_TAR_GNU_EXTENSIONS
 	case 'L': {
 			longname = xmalloc(tar_entry->size + 1);
-			archive_xread_all((int) tar_stream, longname, tar_entry->size);
+                        if(fread(longname, tar_entry->size, 1, tar_stream) != 1)
+                                return NULL;
 			longname[tar_entry->size] = '\0';
 			archive_offset += tar_entry->size;
 
@@ -665,7 +666,8 @@ file_header_t *get_header_tar(FILE *tar_stream)
 		}
 	case 'K': {
 			linkname = xmalloc(tar_entry->size + 1);
-			archive_xread_all((int) tar_stream, longname, tar_entry->size);
+                        if(fread(longname, tar_entry->size, 1, tar_stream) != 1)
+                                return NULL;
 			linkname[tar_entry->size] = '\0';
 			archive_offset += tar_entry->size;
 
